from setuptools import setup
setup(name='easy nlp',
version = '0.1.5',
description = "NLP made easy.",
long_description = "NLP made easy. Built on the top of spacy." ,
url = "https://github.com/RajeshNathani/easy-nlp/tree/master",
author = "Rajesh Nathani" ,
author_email = "rajeshnathani055@gmail.com",
license = "MIT" ,
install_requires =['spacy==2.2'],
packages = ['easy_nlp'] , zip_safe = False,

)